/*
 *    ApplyXSLT.java
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package org.greenstone.gatherer.util;

import java.io.*;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.stream.StreamSource;
import javax.xml.transform.stream.StreamResult;


public class ApplyXSLT
{
    static public void main(String[] args)
    {
	if (args.length < 2) {
	    System.err.println("Usage: ApplyXSLT <XSLfile> <XMLfile>");
	}

	System.setProperty("javax.xml.transform.TransformerFactory",
			   "org.apache.xalan.processor.TransformerFactoryImpl");
	TransformerFactory t_factory = null;
	try {
	    t_factory = org.apache.xalan.processor.TransformerFactoryImpl.newInstance();
	}
	catch (Exception ex) {
	    System.err.println("XMLTransformer() exception " + ex.getMessage());
	}

	String stylesheet = args[0];
	String xml_in = args[1];
	try {
	    // Use the TransformerFactory to process the stylesheet Source and generate a Transformer
	    Transformer transformer = t_factory.newTransformer(new StreamSource(stylesheet));

	    // Use the Transformer to transform an XML Source and send the output to a Result object
	    StringWriter output = new StringWriter();
	    transformer.transform(new StreamSource(xml_in), new StreamResult(output));
	    System.out.println(output.toString());
	}
	catch (TransformerConfigurationException ex) {
	    System.err.println("XMLTransformer: couldn't create transformer object: " + ex.getMessageAndLocation());
	    System.err.println(ex.getLocationAsString());  
	}
	catch (TransformerException ex) {
	    System.err.println("XMLTransformer: couldn't transform the source: " + ex.getMessage());
	}
    }
}
